'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

exports.default = function (command, flags) {
    switch (command) {
        case 'test':
            var filePath = _path2.default.resolve(process.cwd(), flags.src || defaults.file);
            var config = Object.assign({}, defaults.config, JSON.parse(_gracefulFs2.default.readFileSync(filePath), 'utf8'));
            var tests = config.tests,
                platforms = config.platforms,
                mocha = config.mocha,
                token = config.token;


            platforms.map(function (platform) {
                return function () {
                    return (0, _runner2.default)(tests, mocha, platform, config[platform], token);
                };
            }).reduce(_q2.default.when, (0, _q2.default)()); // eslint-disable-line
            break;
        case 'init':
            console.log('Hi, I will help you to setup chatic for this project.');

            var questions = [{
                type: 'input',
                message: 'Enter the name of file for chatic config or just press enter',
                name: 'file',
                default: defaults.file,
                validate: function validate() {
                    return true;
                }
            }, {
                type: 'input',
                message: 'Enter path to tests',
                name: 'tests',
                default: defaults.config.tests,
                validate: function validate() {
                    return true;
                }
            }, {
                type: 'checkbox',
                message: 'Select platforms',
                name: 'platforms',
                choices: [{
                    name: 'facebook'
                }, {
                    name: 'slack'
                }],
                validate: function validate(answer) {
                    if (answer.length < 1) {
                        return 'You must choose at least one platform.';
                    }
                    return true;
                }
            }, {
                type: 'input',
                message: 'Please provide name of a bot for facebook',
                name: 'facebook',
                when: function when(answers) {
                    return answers.platforms.includes('facebook');
                },
                validate: function validate(answer) {
                    if (answer.length < 1) {
                        return 'I need to know bot name in order to open bot before test execution';
                    }

                    return true;
                }
            }, {
                type: 'input',
                message: 'Please provide name of a bot for slack',
                name: 'slack',
                when: function when(answers) {
                    return answers.platforms.includes('slack');
                },
                validate: function validate(answer) {
                    if (answer.length < 1) {
                        return 'I need to know bot name in order to open bot before test execution';
                    }

                    return true;
                }
            }, {
                type: 'input',
                message: 'Please provide your token',
                name: 'token',
                validate: function validate(answer) {
                    if (answer.length < 1) {
                        return '\n                            Please provide access token.\n                            If you don\'t have one, contact guys by email hello@chatic.io\n                        ';
                    }

                    return true;
                }
            }];

            _inquirer2.default.prompt(questions).then(function (answers) {
                var conf = Object.assign({}, answers);
                var file = _path2.default.resolve(process.cwd(), answers.file === '' ? defaults.file : answers.file);

                ['slack', 'facebook'].filter(function (platform) {
                    return conf.platforms.includes(platform);
                }).forEach(function (platform) {
                    conf[platform] = {
                        name: conf[platform]
                    };
                });

                _gracefulFs2.default.writeFileSync(file, JSON.stringify(conf, null, 4), 'utf8');

                console.log(_chalk2.default.green('Hooray! You are ready to test.'));
            });
            break;
        default:
            console.log('\n            Don\'t know \'' + command + '\'.\n            Please use ' + _chalk2.default.green('chatic help') + ' for getting more information.\n        ');
    }
};

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _gracefulFs = require('graceful-fs');

var _gracefulFs2 = _interopRequireDefault(_gracefulFs);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _q = require('q');

var _q2 = _interopRequireDefault(_q);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _runner = require('./runner');

var _runner2 = _interopRequireDefault(_runner);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaults = {
    file: '.chaticconf',
    config: {
        tests: './test/**/*.js',
        platforms: []
    }
};

Object.freeze(defaults);