'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _mocha = require('mocha');

var _mocha2 = _interopRequireDefault(_mocha);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _q = require('q');

var _q2 = _interopRequireDefault(_q);

var _cliSpinner = require('cli-spinner');

var _api = require('./api');

var _api2 = _interopRequireDefault(_api);

require('./mocha/bdd');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (tests, mochaConfig, platform, config, token) {
    Object.keys(require.cache).forEach(function (file) {
        return delete require.cache[file];
    });
    var deferred = _q2.default.defer();
    var files = _glob2.default.sync(tests, { absolute: true });
    var api = (0, _api2.default)(platform, token);
    var mocha = new _mocha2.default(Object.assign({ timeout: 30000 }, mochaConfig, { ui: 'chatic' }));
    var spinner = new _cliSpinner.Spinner('%s Connecting to idle node...');
    var onError = function onError() {
        var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Something went wrong. I can\'t connect to the server';

        spinner.stop();
        var error = _chalk2.default.red(message);

        deferred.reject(new Error(error));
    };

    spinner.setSpinnerString(0);
    spinner.start();

    api.connect(config).then(function (response) {
        var httpResponse = response.httpResponse;


        spinner.stop();

        switch (httpResponse.statusCode) {
            case 200:
                console.log('\n' + _chalk2.default.green('Connected'));
                global.chatic = api;

                files.forEach(function (file) {
                    return mocha.addFile(file);
                });

                mocha.run(function (failures) {
                    process.on('exit', function () {
                        return api.disconnect().then(function () {
                            return process.exit(failures);
                        });
                    }); // eslint-disable-line
                }).on('end', function () {
                    api.disconnect().then(function () {
                        delete global.chatic;
                        deferred.resolve();
                    });
                });
                break;
            case 401:
                onError('Wrong credentials');
                break;
            case 423:
                onError('Can\'t find idle node for testing');
                break;
            default:
                onError();
        }
    }, function () {
        return onError();
    });

    return deferred.promise;
};